# นี่คือตัวอย่างโปรแกรมสำหรับการเรียน     OPP

### วิธีติดตั้ง

เปิด CMD / Terminal

```python
pip install angryduckschool
```

### วิธีเล่น

เปิด IDLE ขึ้นมาแล้วพิมพ์...

```python
from angryduckschool import Student , SpecialStudent
print('=======1 Jan ========')
student0 = SpecialStudent('Mark Zukerberg','Bill Gates')
student0.ShowEXP()
student0.AskEXP()
student0.ShowEXP()
student1 = Student('Albert')
print(student1.name)
student1.Hello()

print('--------------------')

student2 = Student('Steve')
print(student2.name)
student2.Hello()
print('=======2 Jan ========')
print('-------Uncle: Who want to learn coding?---(10 exp)---')


print('=======3 Jan ========')
student1.name = 'Albert Einstein'
print('Now exp of each people:')
student1.AddEXP(10)
print(student1.name,student1.exp)
print(student2.name,student2.exp)

print('=======4 Jan ========')

for i in range(5):
	student2.Coding()

student1.ShowEXP()
student2.ShowEXP()

print('--------------------')


พัฒนาโดย: Angryduck888



